<!doctype html>
<html lang="en">
  <head>
    <!-- Required meta tags -->
    <meta charset="utf-8" />
    <meta
      name="viewport"
      content="width=device-width, initial-scale=1, shrink-to-fit=no"
    />

    <!-- Bootstrap CSS -->
    <link
      href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css"
      rel="stylesheet"
      integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC"
      crossorigin="anonymous"
    />

    <style>
      .image-container {
        float: left;
        width: 33.33%;
        box-sizing: border-box;
        padding: 10px;
        text-align: center;
      }

      .image-container img {
        max-width: 100%;
        height: auto;
      }

      .clear-after-images::before {
        content: "";
        display: table;
        clear: both;
      }

      @media (max-width: 768px) {
        .image-container {
          width: 50%;
        }
      }

      @media (max-width: 480px) {
        .image-container {
          width: 100%;
        }
      }
    </style>

    <title>MNT Bench</title>
    <link
      rel="shortcut icon"
      href="{{ url_for('static', filename='favicon.ico') }}"
    />
  </head>
  <body>
    <!-- Image and text -->
    <nav class="navbar navbar-expand-lg navbar-light bg-light fixed-top">
      <a class="navbar-brand" href="/mntbench">
        <img
          src="{{ url_for('static', filename='tum_logo.svg') }}"
          alt=""
          width="50"
          height="24"
          class="d-inline-block align-text-top"
        />
        MNT Bench
      </a>
      <button
        class="navbar-toggler"
        type="button"
        data-toggle="collapse"
        data-target="#navbarNavAltMarkup"
        aria-controls="navbarNavAltMarkup"
        aria-expanded="false"
        aria-label="Toggle navigation"
      >
        <span class="navbar-toggler-icon"></span>
      </button>
      <div class="collapse navbar-collapse" id="navbarNavAltMarkup">
        <div class="navbar-nav">
          <a class="nav-item nav-link" href="index">Benchmarks</a>
          <a class="nav-item nav-link active" href="description "
            >Level and File Descriptions</a
          >
          <a
            class="nav-item nav-link"
            href="https://www.cda.cit.tum.de/research/fcn/"
            target="_blank"
            >More on our Work</a
          >
          <a class="nav-item nav-link" href="legal">Legal Information</a>
        </div>
      </div>
    </nav>
    <div class="col-xs-12" style="height: 80px"></div>

    <div class="container">
      <h1>MNT Bench: Library Description and File Format</h1>
      <p>Benchmarks are provided for two different gate libraries:</p>
      <ul>
        <li>
          <a
            href="https://ieeexplore.ieee.org/document/7538997/"
            target="_blank"
            >QCA ONE</a
          >: Used for QCA circuits.
        </li>
        <li>
          <a
            href="https://dl.acm.org/doi/10.1145/3489517.3530525"
            target="_blank"
            >Bestagon</a
          >: Used for SiDB circuits.
        </li>
      </ul>
      <p>and up to five different clocking schemes:</p>
      <div class="image-container">
        <p>
          <a href="https://ieeexplore.ieee.org/document/1717097" target="_blank"
            >2DDWave</a
          >
        </p>
        <img src="{{ url_for('static', filename='2ddwave.png')}}" />
      </div>

      <div class="image-container">
        <p>
          <a href="https://ieeexplore.ieee.org/document/7219390" target="_blank"
            >USE</a
          >
        </p>
        <img src="{{ url_for('static', filename='use.png')}}" />
      </div>

      <div class="image-container">
        <p>
          <a
            href="https://www.tandfonline.com/doi/abs/10.1080/21681724.2019.1570551"
            target="_blank"
            >RES</a
          >
        </p>
        <img src="{{ url_for('static', filename='res.png')}}" />
      </div>

      <div class="image-container">
        <p>
          <a
            href="https://link.springer.com/content/pdf/10.1007/s10470-020-01760-4.pdf"
            target="_blank"
            >ESR</a
          >
        </p>
        <img src="{{ url_for('static', filename='esr.png')}}" />
      </div>

      <div class="image-container">
        <p>
          <a href="https://ieeexplore.ieee.org/document/573740" target="_blank"
            >ROW</a
          >
        </p>
        <img src="{{ url_for('static', filename='row.png')}}" />
      </div>

      <p class="clear-after-images">Used File Format:</p>
      <ul>
        <li>
          Not every benchmark is necessarily available for every possible
          configuration of the available options. For example, for large
          circuits, layouts using the USE clocking scheme have not been found
          yet.
        </li>
        <li>
          Since the <em>.zip</em> file may be composed of numerous files
          (currently, we offer more than 150 benchmark circuits), the following
          naming convention is used for the respective files:
        </li>
      </ul>
    </div>

    <div class="container">
      <table class="table-sm">
        <caption>
          Level Descriptions
        </caption>
        <thead>
          <tr>
            <th scope="col" style="width: 15%">Level</th>
            <th scope="col" style="width: 80%">Filename</th>
            <th scope="col" style="width: 5%">Example</th>
          </tr>
        </thead>
        <tbody>
          <tr>
            <td style="vertical-align: top">Gate Level</td>
            <td style="vertical-align: top">
              <span style="font-family: monospace"
                >&lt;benchmark_identifier&gt;_&lt;library&gt;_&lt;clocking_scheme&gt;.fgl</span
              >
            </td>
            <td style="vertical-align: top">
              <span style="font-family: monospace">mux21_Bestagon_ROW.fgl</span>
            </td>
          </tr>
          <tr>
            <td style="vertical-align: top">Network Level</td>
            <td style="vertical-align: top">
              <span style="font-family: monospace"
                >&lt;benchmark_identifier&gt;.v</span
              >
            </td>
            <td style="vertical-align: top">
              <span style="font-family: monospace">mux21.v</span>
            </td>
          </tr>
        </tbody>
      </table>
    </div>

    <div class="col-xs-12" style="height: 50px"></div>

    <!-- Optional JavaScript -->
    <!-- jQuery first, then Popper.js, then Bootstrap JS -->
    <script
      src="https://code.jquery.com/jquery-3.2.1.slim.min.js"
      integrity="sha384-KJ3o2DKtIkvYIK3UENzmM7KCkRr/rE9/Qpg6aAZGJwFDMVNA/GpGFF93hXpG5KkN"
      crossorigin="anonymous"
    ></script>
    <script
      src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js"
      integrity="sha384-ApNbgh9B+Y1QKtv3Rn7W3mgPxhU9K/ScQsAP7hUibX39j7fakFPskvXusvfa0b4Q"
      crossorigin="anonymous"
    ></script>
    <script
      src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js"
      integrity="sha384-JZR6Spejh4U02d8jOt6vLEHfe/JQGiRRSQQxSfFWpi1MquVdAyjUar5+76PVCmYl"
      crossorigin="anonymous"
    ></script>
  </body>
</html>
